@@ -18,12 +18,16 @@ Example: ::
     def index(args):
         return 'Hello ' + args['name']
 """
+import logging
+
 from flask import request, abort as flask_abort
 from werkzeug.exceptions import HTTPException
 
 from webargs import core
 from webargs.core import text_type
 
+logger = logging.getLogger(__name__)
+
 def abort(http_status_code, **kwargs):
     """Raise a HTTPException for the given http_status_code. Attach any keyword
     arguments to the exception for later processing.
@@ -78,7 +82,10 @@ class FlaskParser(core.Parser):
         """Handles errors during parsing. Aborts the current HTTP request and
         responds with a 400 error.
         """
-        abort(400, message=text_type(error), exc=error)
+        logger.error(error)
+        status_code = getattr(error, 'status_code', 400)
+        data = getattr(error, 'data', {})
+        abort(status_code, message=text_type(error), exc=error, **data)
 
     def parse(self, argmap, req=None, *args, **kwargs):
         """Parses the request using the given arguments map.
