@@ -9,7 +9,7 @@ Example: ::
 
     class HelloHandler(tornado.web.RequestHandler):
 
-        @use_args({'name': Arg(str)})
+        @use_args({'name': Arg(str, default='World')})
         def get(self, args):
             response = {'message': 'Hello {}'.format(args['name'])}
             self.write(response)
@@ -17,11 +17,13 @@ Example: ::
 
 import json
 import functools
+import logging
 
 import tornado.web
 
 from webargs import core
 
+logger = logging.getLogger(__name__)
 
 def parse_json(s):
     if isinstance(s, bytes):
@@ -46,6 +48,10 @@ def get_value(d, name, multiple):
 class TornadoParser(core.Parser):
     """Tornado request argument parser."""
 
+    def __init__(self, *args, **kwargs):
+        super(TornadoParser, self).__init__(*args, **kwargs)
+        self.json = None
+
     def parse_json(self, req, name, arg):
         """Pull a json value from the request."""
         return get_value(self.json, name, arg.multiple)
@@ -79,7 +85,10 @@ class TornadoParser(core.Parser):
         """Handles errors during parsing. Raises a `tornado.web.HTTPError`
         with a 400 error.
         """
-        raise tornado.web.HTTPError(400, error.args[0])
+        logger.error(error)
+        status_code = getattr(error, 'status_code', 400)
+        data = getattr(error, 'data', {})
+        raise tornado.web.HTTPError(status_code, error.args[0], **data)
 
     def _parse_json_body(self, req):
         content_type = req.headers.get('Content-Type')
